@@ -69,6 +69,12 @@ impl NodeTypeConfig {
     pub fn meta(&self) -> &HashMap<String, String> {
         &self.meta
     }
+
+    pub fn extend(mut self, other: &Self) -> Self {
+        self.style = self.style.extend(&other.style);
+        self.meta.extend(other.meta.to_owned());
+        self
+    }
 }
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
@@ -84,7 +90,7 @@ pub struct NodeTypesConfig {
     pub symlink: NodeTypeConfig,
 
     #[serde(default)]
-    pub mime_essence: HashMap<String, NodeTypeConfig>,
+    pub mime_essence: HashMap<String, HashMap<String, NodeTypeConfig>>,
 
     #[serde(default)]
     pub extension: HashMap<String, NodeTypeConfig>,
@@ -110,7 +116,7 @@ impl NodeTypesConfig {
     }
 
     /// Get a reference to the node types config's mime essence.
-    pub fn mime_essence(&self) -> &HashMap<String, NodeTypeConfig> {
+    pub fn mime_essence(&self) -> &HashMap<String, HashMap<String, NodeTypeConfig>> {
         &self.mime_essence
     }
 
@@ -166,9 +172,9 @@ pub struct UiElement {
 }
 
 impl UiElement {
-    pub fn extend(mut self, other: Self) -> Self {
-        self.format = other.format.or(self.format);
-        self.style = self.style.extend(other.style);
+    pub fn extend(mut self, other: &Self) -> Self {
+        self.format = other.format.to_owned().or(self.format);
+        self.style = self.style.extend(&other.style);
         self
     }
 
@@ -431,10 +437,13 @@ impl PanelUi {
 #[serde(deny_unknown_fields)]
 pub struct GeneralConfig {
     #[serde(default)]
-    pub show_hidden: Option<bool>,
+    pub enable_mouse: bool,
 
     #[serde(default)]
-    pub read_only: Option<bool>,
+    pub show_hidden: bool,
+
+    #[serde(default)]
+    pub read_only: bool,
 
     #[serde(default)]
     pub cursor: UiElement,
@@ -475,12 +484,12 @@ pub struct GeneralConfig {
 
 impl GeneralConfig {
     /// Get a reference to the general config's show hidden.
-    pub fn show_hidden(&self) -> Option<bool> {
+    pub fn show_hidden(&self) -> bool {
         self.show_hidden
     }
 
     /// Get a reference to the general config's read only.
-    pub fn read_only(&self) -> Option<bool> {
+    pub fn read_only(&self) -> bool {
         self.read_only
     }
 
@@ -543,6 +552,11 @@ impl GeneralConfig {
     pub fn panel_ui(&self) -> &PanelUi {
         &self.panel_ui
     }
+
+    /// Get a reference to the general config's enable mouse.
+    pub fn enable_mouse(&self) -> bool {
+        self.enable_mouse
+    }
 }
 
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
@@ -968,10 +982,10 @@ pub struct PanelUiConfig {
 }
 
 impl PanelUiConfig {
-    pub fn extend(mut self, other: Self) -> Self {
-        self.title = self.title.extend(other.title);
-        self.borders = other.borders.or(self.borders);
-        self.style = self.style.extend(other.style);
+    pub fn extend(mut self, other: &Self) -> Self {
+        self.title = self.title.extend(&other.title);
+        self.borders = other.borders.to_owned().or(self.borders);
+        self.style = self.style.extend(&other.style);
         self
     }
     /// Get a reference to the block config's borders.
